PyPot development started in mid 2012 at Inria Flowers, Bordeaux - France. Main authors are (and/or have been):

* Pierre Rouanet
* Matthieu Lapeyre
* Haylee Fogg

People who have contributed to PyPot:

* Rémi Barraquand